<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans svn://zone.spip.org/spip-zone/_core_/plugins/jquery_ui/lang/
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// J
	'jqueryui_description' => 'Ce plugin implémente dans SPIP la bibliothèque complémentaire jQuery UI autorisant la création de composants graphiques dynamiques : onglets, drag & drop, barres de progression...
Les fonctionnalités de cette bibliothèque se divisent en 3 catégories :
-* {{Les interactions}}. Elles permettent de donner des propriétés très intéressantes à des éléments HTML, comme le fait de pouvoir être attrapés et déplacés avec la souris (drag & drop), d’être redimensionnés comme une fenêtre, ou encore d’être sélectionnés comme des icones sur le bureau de votre OS.
-* {{Les Widgets}}. Ce sont des objets « clé en main » qui proposent des fonctionnalités de haut niveau comme le DatePicker par exemple, qui affiche un calendrier permettant de sélectionner une date.
-* {{Les effects}}. Ils enrichissement les effets par défaut proposés par jQuery (fadeIn, slideUp...). Grâce à jQuery UI, il est par exemple possible d’animer la propriété CSS background-color avec .animate() ou encore d’ajouter des transitions lors des addClass/removeClass...',
	'jqueryui_slogan' => 'Animations, effets et widgets jQuery'
);

?>
